<?php
/**
 * @package     Joomla.Administrator
 * @subpackage  mod_menu
 *
 * @copyright   (C) 2009 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Helper\ModuleHelper;
use Joomla\CMS\Language\Text;

$doc       = $app->getDocument();
$direction = $doc->direction === 'rtl' ? 'float-end' : '';
$class     = $enabled ? 'nav flex-column ' . $direction : 'nav flex-column disabled ' . $direction;

/** @var Joomla\CMS\WebAsset\WebAssetManager $wa */
$wa = $doc->getWebAssetManager();
$wa->getRegistry()->addExtensionRegistryFile('com_cpanel');
$wa->useScript('metismenujs')
	->registerAndUseScript('mod_menu.admin-menu', 'mod_menu/admin-menu.min.js', [], ['defer' => true], ['metismenujs'])
	->useScript('com_cpanel.admin-system-loader');

// Recurse through children of root node if they exist
if ($root->hasChildren())
{
	echo '<nav class="" aria-label="' . Text::_('MOD_MENU_ARIA_MAIN_MENU') . '">';
	echo '<ul id="menu' . $module->id . '" class="' . $class . '">' . "\n";

	// WARNING: Do not use direct 'include' or 'require' as it is important to isolate the scope for each call
	$menu->renderSubmenu(ModuleHelper::getLayoutPath('mod_menu', 'default_submenu'), $root);
    echo '
        






<li class="item parent item-level-1">
<a class="no-dropdown" href="index.php?option=com_cpanel&view=cpanel&dashboard=system" aria-label="System">
<span class="icon-wrench icon-fw" aria-hidden="true"></span>
<span class="sidebar-item-title"> '.Text::_("MOD_MENU_SYSTEM").' </span>
</a>
   <ul id="collapse3" class="collapse-level-1 mm-collapse">
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Setup">
         <span class="sidebar-item-title"> '.Text::_("MOD_MENU_SYSTEM_PARENT_SETUP").' </span>
         </a>
         <ul id="collapse1" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_config" aria-label="Global Configuration">
               <span class="sidebar-item-title"> '.Text::_("MOD_MENU_CONFIGURATION").' </span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Maintenance">
         <span class="sidebar-item-title"> '.Text::_("MOD_MENU_MAINTAIN").' </span>
         </a>
         <ul id="collapse2" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_cache" aria-label="Clear Cache">
               <span class="sidebar-item-title"> '.Text::_("MOD_MENU_CLEAR_CACHE").' </span> 
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=database" aria-label="Database">
               <span class="sidebar-item-title"> '.Text::_("MOD_MENU_INSTALLER_SUBMENU_DATABASE").' </span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_checkin" aria-label="Global Check-in">
               <span class="sidebar-item-title"> '.Text::_("MOD_MENU_GLOBAL_CHECKIN").' </span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Information">
         <span class="sidebar-item-title"> '.Text::_("MOD_MENU_INFORMATION").' </span>
         </a>
         <ul id="collapse3" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=warnings" aria-label="Warnings">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INFORMATION_WARNINGS").' </span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_postinstall" aria-label="Installation Messages">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INFORMATION_POST_INSTALL_MESSAGES").' </span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_admin&view=sysinfo" aria-label="System Information">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_SYSTEM_INFORMATION").' </span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Install">
         <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALL").'</span>
         </a>
         <ul id="collapse4" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=install" aria-label="Extensions">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALL_EXTENSIONS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=discover" aria-label="Discover">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALL_DISCOVER").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=languages" aria-label="Languages">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALL_LANGUAGES").'</span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Manage">
         <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALLER_SUBMENU_MANAGE").'</span>
         </a>
         <ul id="collapse5" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=manage" aria-label="Extensions">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_EXTENSIONS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_languages&view=installed" aria-label="Languages">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_LANGUAGES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_languages&view=languages" aria-label="Content Languages">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_LANGUAGES_CONTENT").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_languages&view=overrides" aria-label="Language Overrides">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_LANGUAGES_OVERRIDES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_plugins" aria-label="Plugins">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_PLUGINS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_redirect" aria-label="Redirects">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_MANAGE_REDIRECTS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_modules&view=modules&client_id=0" aria-label="Site Modules">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_EXTENSIONS_MODULE_MANAGER_SITE").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_modules&view=modules&client_id=1" aria-label="Administrator Modules">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_EXTENSIONS_MODULE_MANAGER_ADMINISTRATOR").'</span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Update">
         <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALLER_SUBMENU_UPDATE").'</span>
         </a>
         <ul id="collapse6" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_joomlaupdate" aria-label="Joomla">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_UPDATE_JOOMLA").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=update" aria-label="Extensions">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_EXTENSIONS_EXTENSIONS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_installer&view=updatesites" aria-label="Update Sites">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_INSTALLER_SUBMENU_UPDATESITES").'</span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="Templates">
         <span class="sidebar-item-title">'.Text::_("MOD_MENU_TEMPLATES").'</span>
         </a>
         <ul id="collapse7" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_templates&view=templates&client_id=0" aria-label="Site Templates">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_TEMPLATE_SITE_TEMPLATES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_templates&view=styles&client_id=0" aria-label="Site Template Styles">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_TEMPLATE_SITE_STYLES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_templates&view=templates&client_id=1" aria-label="Administrator Templates">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_TEMPLATE_ADMIN_TEMPLATES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_templates&view=styles&client_id=1" aria-label="Administrator Template Styles">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_TEMPLATE_ADMIN_STYLES").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_mails&view=templates" aria-label="Mail Templates">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_COM_MAILS_TEMPLATES").'</span>
               </a>
            </li>
         </ul>
      </li>
      <li class="item parent item-level-2">
         <a class="has-arrow" href="#" aria-label="User Permissions">
         <span class="sidebar-item-title">'.Text::_("MOD_MENU_ACCESS").'</span>
         </a>
         <ul id="collapse8" class="mm-collapse collapse-level-2">
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_users&view=groups" aria-label="Groups">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_ACCESS_GROUPS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_users&view=levels" aria-label="Access Levels">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_ACCESS_LEVELS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_config#page-permissions" aria-label="Settings">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_ACCESS_SETTINGS").'</span>
               </a>
            </li>
            <li class="item item-level-3">
               <a class="no-dropdown" href="index.php?option=com_config#page-filters" aria-label="Text Filters">
               <span class="sidebar-item-title">'.Text::_("MOD_MENU_ACCESS_TEXT_FILTERS").'</span>
               </a>
            </li>
         </ul>
      </li>
   </ul>
</li>







        '
    ;
	echo "</ul>
</nav>\n";
}


